@@ -11,8 +11,12 @@ xsewma.arl <- function(lx, cx, ls, csu, df, mu, sigma,
     stop("cx has to be positive")
   if (csu<=0) 
     stop("csu has to be positive")
-  if (csu<0)
+  if (csl<0)
     stop("clu has to be non-negative")
+  if ( sigma<=0 )
+    stop("sigma must be positive")
+  if ( df<1 )
+    stop("df must be larger than or equal to 1")
   s_squared <- as.numeric(s2.on)
   if ( !(s_squared %in% c(0,1)) )
     stop("wrong value for s2.on")
